@@ -42,12 +42,12 @@ def destroy_node(node):
 
 
 def replace_tag(tag, new_tag_str):
+	assert tag.parent is not None
 	newTags = []
 	if new_tag_str:
 		doc = bs4.BeautifulSoup(new_tag_str, 'html5lib')
-		if (len(doc.body.contents) > 0):
-			newTags = [f for f in doc.body.contents]
-			newTags = [f.extract() for f in newTags]
+		if len(doc.body.contents) > 0:
+			newTags = [f.extract() for f in doc.body.contents]
 			prev = tag
 			for newTag in newTags:
 				prev.insert_after(newTag)
